"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectCommentFileNames = void 0;
const utils_1 = require("../utils");
const collectCommentFileNames = async (dependencies, filePathGlobs, typescriptConfiguration) => {
    if (filePathGlobs === true) {
        if (!typescriptConfiguration) {
            return new Error("--comments indicated to convert files listed in a tsconfig.json, but one was not found on disk or specified by with --typescript.");
        }
        const includeList = (0, utils_1.uniqueFromSources)(typescriptConfiguration.files, typescriptConfiguration.include);
        // Remove directories specified in the include list. Ignore
        // Errors as they'll be handled when reading the file.
        const includeListFiles = (await Promise.all(includeList.map(dependencies.fileSystem.directoryExists)))
            .map((isDirectory, i) => {
            if (isDirectory) {
                return null;
            }
            return includeList[i];
        })
            .filter((item) => typeof item === "string");
        return {
            exclude: typescriptConfiguration.exclude,
            include: includeListFiles,
        };
    }
    if (typeof filePathGlobs === "string" && filePathGlobs.endsWith(".json")) {
        const findResult = await dependencies.findTypeScriptConfiguration(filePathGlobs);
        if (findResult instanceof Error) {
            return findResult;
        }
        return await (0, exports.collectCommentFileNames)(dependencies, true, findResult);
    }
    return {
        include: (0, utils_1.uniqueFromSources)(filePathGlobs),
    };
};
exports.collectCommentFileNames = collectCommentFileNames;
//# sourceMappingURL=collectCommentFileNames.js.map